"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Csrf = /** @class */ (function () {
    function Csrf(csrfHeader, getToken) {
        var _this = this;
        this.authorize = function (request) {
            return request([_this.csrfHeader, _this.getToken()]);
        };
        this.getToken = getToken || Csrf.getTokenDefault;
        this.csrfHeader = csrfHeader || 'X-CSRF-TOKEN';
    }
    // 1) Look for csrf_token cookie
    // "csrf_token={{ csrf_token() }}; Path=/; Domain=.procore.com; SameSite=Strict; Secure=true;"
    // 2) Look for csrf-token meta tag
    // <head>
    //   <meta name="csrf-token" content="{{ csrf_token() }}">
    // </head>
    // 3) Return ""
    // https://cheatsheetseries.owasp.org/cheatsheets/Cross-Site_Request_Forgery_Prevention_Cheat_Sheet.html
    Csrf.getTokenDefault = function () {
        var cookieCsrf = document.cookie.match(/(?:^|;)\s*csrf_token\s*=\s*([^;]+)/);
        if (cookieCsrf) {
            return decodeURIComponent(cookieCsrf.pop());
        }
        var metaCsrf = document
            .querySelector('meta[name="csrf-token"]')
            .getAttribute('content');
        return (metaCsrf !== undefined && metaCsrf !== null && metaCsrf.length > 0) ? metaCsrf : '';
    };
    return Csrf;
}());
function csrf(csrfHeader, getToken) {
    return new Csrf(csrfHeader, getToken);
}
exports.default = csrf;
